@@ -37,6 +37,7 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
   if (length(which(ls() == "rmc.header.structure")) == 0) rmc.header.structure = c()
   if (length(which(ls() == "rmc.check4timegaps")) == 0) rmc.check4timegaps = FALSE
   if (length(which(ls() == "rmc.noise")) == 0) rmc.noise = FALSE
+  if (length(which(ls() == "rmc.doresample")) == 0) rmc.doresample = FALSE
   if (length(chunksize) == 0) chunksize = 1
   if (chunksize > 1) chunksize = 1
   if (chunksize < 0.4) chunksize = 0.4
@@ -146,7 +147,8 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
                             rmc.headername.sn = rmc.headername.sn,
                             rmc.headername.recordingid = rmc.headername.sn,
                             rmc.header.structure = rmc.header.structure,
-                            rmc.check4timegaps = rmc.check4timegaps)
+                            rmc.check4timegaps = rmc.check4timegaps,
+                            rmc.doresample=rmc.doresample)
     P = accread$P
     filequality = accread$filequality
     filetooshort = filequality$filetooshort
@@ -343,7 +345,7 @@ g.calibrate = function(datafile,use.temp=TRUE,spherecrit=0.3,minloadcrit=72,prin
           QC = "recalibration not done because not enough points on all sides of the sphere"
         }
       } else {
-        cat("\nNo non-movement found\n")
+        cat(" No non-movement found\n")
         QC = "recalibration not done because no non-movement data available"
         meta_temp = c()
       }
