@@ -111,60 +111,69 @@ g.getstarttime = function(datafile,P,header,mon,dformat,desiredtz,selectdaysfile
       topline = as.matrix(colnames(as.matrix(read.csv(datafile,nrow=1,skip=0))))
       topline = topline[1]  #To avoid dots
       options(warn=0)
-      B1 = length(unlist(strsplit(topline,"MM[.]dd[.]yyyy")))
-      B2 = length(unlist(strsplit(topline,"M[.]d[.]yyyy")))
-      B6 = length(unlist(strsplit(topline,"M[.]dd[.]yyyy")))
-      B7 = length(unlist(strsplit(topline,"MM[.]d[.]yyyy")))
-      B3 = length(unlist(strsplit(topline,"dd[.]MM[.]yyyy")))
-      B4 = length(unlist(strsplit(topline,"d[.]M[.]yyyy")))
-      B5 = length(unlist(strsplit(topline,"d[.]MM[.]yyyy")))
-      B8 = length(unlist(strsplit(topline,"dd[.]M[.]yyyy")))
-
-      B9 = length(unlist(strsplit(topline,"yyyy[.]MM[.]dd")))
-      B10 = length(unlist(strsplit(topline,"yyyy[.]M[.]d")))
-      B11 = length(unlist(strsplit(topline,"yyyy[.]MM[.]d")))
-      B12 = length(unlist(strsplit(topline,"yyyy[.]M[.]dd")))
-
-      B13 = length(unlist(strsplit(topline,"yyyy[.]dd[.]MM")))
-      B14 = length(unlist(strsplit(topline,"yyyy[.]d[.]M")))
-      B15 = length(unlist(strsplit(topline,"yyyy[.]d[.]MM")))
-      B16 = length(unlist(strsplit(topline,"yyyy[.]dd[.]M")))
-
-      if (B1 > 1 | B2 > 1 | B6 > 1 | B7 > 1) {
-        starttime0 = as.POSIXlt(starttime,format='%m/%d/%Y %H:%M:%S')
-        if(is.na(starttime0) == TRUE) {
-          starttime0 = as.POSIXlt(starttime,format='%m-%d-%Y %H:%M:%S')
-          if(is.na(starttime0) == TRUE) {
-            starttime0 = as.POSIXlt(starttime,format='%m.%d.%Y %H:%M:%S')
-          }
-        }
-      } else if (B3 > 1 | B4 > 1 | B5 > 1 | B8 > 1) {
-        starttime0 = as.POSIXlt(starttime,format='%d/%m/%Y %H:%M:%S')
-        if(is.na(starttime0) == TRUE) {
-          starttime0 = as.POSIXlt(starttime,format='%d-%m-%Y %H:%M:%S')
-          if(is.na(starttime0) == TRUE) {
-            starttime0 = as.POSIXlt(starttime,format='%d.%m.%Y %H:%M:%S')
-          }
-        }
-      } else if (B9 > 1 | B10 > 1 | B11 > 1 | B12 > 1) {
-        starttime0 = as.POSIXlt(starttime,format='%Y/%m/%d %H:%M:%S')
-        if(is.na(starttime0) == TRUE) {
-          starttime0 = as.POSIXlt(starttime,format='%d-%m-%Y %H:%M:%S')
-          if(is.na(starttime0) == TRUE) {
-            starttime0 = as.POSIXlt(starttime,format='%d.%m.%Y %H:%M:%S')
-          }
-        }
-      } else if (B13 > 1 | B14 > 1 | B15 > 1 | B16 > 1) {
-        starttime0 = as.POSIXlt(starttime,format='%Y/%d/%m %H:%M:%S')
-        if(is.na(starttime0) == TRUE) {
-          starttime0 = as.POSIXlt(starttime,format='%d-%m-%Y %H:%M:%S')
-          if(is.na(starttime0) == TRUE) {
-            starttime0 = as.POSIXlt(starttime,format='%d.%m.%Y %H:%M:%S')
+      # Extraction of date format.
+      # all formats to consider following R date formatting symbols:
+      # Y year including century, y year excluding century, b month as character, m month as a number
+      # Note: year in the middle of a date is assumed to not occur.
+      allformats = c("mdY", "mdy","bdY", "bdy",
+                     "dmY", "dmy", "dbY", "dby",
+                     "Ymd", "ymd", "Ybd", "ybd",
+                     "Ydm", "ydm", "Ydb", "ydb")
+      fc = data.frame(matrix(0,1,length(allformats))) # data.frame to keep track of formats that have been checked
+      names(fc) = allformats
+      # Now systematically go through all possible formats to identify which one it is
+      fc$mdY = length(grep("MM[.]dd[.]yyyy|M[.]d[.]yyyy|M[.]dd[.]yyyy|MM[.]d[.]yyyy",topline))
+      fc$mdy = length(grep("MM[.]dd[.]yy|M[.]d[.]yy|M[.]dd[.]yy|MM[.]d[.]yy",topline))
+      fc$bdY = length(grep("MMM[.]dd[.]yyyy|MMM[.]d[.]yyyy",topline))
+      fc$bdy = length(grep("MMM[.]dd[.]yy|MMM[.]d[.]yy",topline))
+      if (fc$mdY == 1 & fc$mdy == 1) fc$mdy = 0 # not yy when yyyy is also detected
+      if (fc$bdY == 1 & fc$bdy == 1) fc$bdy = 0 # not yy when yyyy is also detected
+      if (fc$mdY == 1 & fc$bdY == 1) fc$mdY = 0 # not M(M) when MMM is also detected for yyyy
+      if (fc$mdy == 1 & fc$bdy == 1) fc$mdy = 0 # not M(M) when MMM is also detected for yy
+      fc$dmY = length(grep("d[.]M[.]yyyy|d[.]MM[.]yyyy",topline))
+      fc$dmy = length(grep("d[.]M[.]yy|d[.]MM[.]yy",topline))
+      fc$dbY = length(grep("d[.]MMM[.]yyyy",topline))
+      fc$dby = length(grep("d[.]MMM[.]yy",topline))
+      if (fc$dmY == 1 & fc$dmy == 1) fc$dmy = 0 # not yy when yyyy is also detected
+      if (fc$dbY == 1 & fc$dby == 1) fc$dby = 0 # not yy when yyyy is also detected
+      if (fc$dmY == 1 & fc$dbY == 1) fc$dmY = 0 # not M(M) when MMM is also detected for yyyy
+      if (fc$dmy == 1 & fc$dby == 1) fc$dmy = 0 # not M(M) when MMM is also detected for yy
+      fc$Ymd = length(grep("yyyy[.]M[.]d|yyyy[.]MM[.]d",topline))
+      fc$ymd = length(grep("yy[.]M[.]d|yy[.]MM[.]d",topline))
+      fc$Ybd = length(grep("yyyy[.]MMM[.]d",topline))
+      fc$ybd = length(grep("yy[.]MMM[.]d",topline))
+      if (fc$Ymd == 1 & fc$ymd == 1) fc$ymd = 0 # not yy when yyyy is also detected
+      if (fc$Ybd == 1 & fc$ybd == 1) fc$ybd = 0 # not yy when yyyy is also detected
+      if (fc$Ymd == 1 & fc$Ybd == 1) fc$Ymd = 0 # not M(M) when MMM is also detected for yyyy
+      if (fc$ymd == 1 & fc$ybd == 1) fc$ymd = 0 # not M(M) when MMM is also detected for yy
+      fc$Ydm = length(grep("yyyy[.]dd[.]MM|yyyy[.]d[.]M|yyyy[.]d[.]MM|yyyy[.]dd[.]M",topline))
+      fc$ydm = length(grep("yy[.]dd[.]MM|yy[.]d[.]M|yy[.]d[.]MM|yy[.]dd[.]M",topline))
+      fc$Ydb = length(grep("yyyy[.]dd[.]MMM|yyyy[.]d[.]MMM",topline))
+      fc$ydb = length(grep("yy[.]dd[.]MMM|yy[.]d[.]MMM",topline))
+      if (fc$Ydm == 1 & fc$ydm == 1) fc$ydm = 0 # not yy when yyyy is also detected
+      if (fc$Ydb == 1 & fc$ydb == 1) fc$ydb = 0 # not yy when yyyy is also detected
+      if (fc$Ydm == 1 & fc$Ydb == 1) fc$Ydm = 0 # not M(M) when MMM is also detected for yyyy
+      if (fc$ydm == 1 & fc$ydb == 1) fc$ydm = 0 # not M(M) when MMM is also detected for yy
+      # Now we can identify which format it is:
+      theformat = names(fc)[which(fc == 1)[1]]
+      if (length(theformat) == 0) warning("date format not recognised")
+      splitformat = unlist(strsplit(theformat,""))
+      # identify separater:
+      if (length(grep("/",starttime)) > 0) {
+        sepa = "/"
+      } else {
+        if (length(grep("-",starttime)) > 0) {
+          sepa = "-"
+        } else {
+          if (length(grep(".",starttime)) > 0) {
+            sepa = "."
+          } else {
+            warning("separater character for dates not identified")
           }
         }
       }
-      rm(starttime)
-      starttime = starttime0
+      expectedformat = paste0('%',splitformat[1],sepa,'%',splitformat[2],sepa,'%',splitformat[3],' %H:%M:%S')
+      starttime = as.POSIXlt(starttime,format=expectedformat)
       lengthheader = 9
     }
   } else if (dformat == 5 & mon == 5) {
