@@ -569,6 +569,9 @@ g.part4 = function(datadir=c(),metadatadir=c(),f0=f0,f1=f1,idloc=1,loglocation =
                       nightsummary[sumi,4] < 36 & daysleeper[j] == TRUE) {  # even more impossible if wake occurs before none, while we previously labelled it as daysleep
                     nightsummary[sumi,4] = nightsummary[sumi,4] + 12 # correction for overcorrection in waking time
                   }
+                  if (nightsummary[sumi,3] == nightsummary[sumi,4] & nightsummary[sumi,4] == 18) { # sleeping from 6pm to 6pm (probably non-wear)
+                    nightsummary[sumi,4] = nightsummary[sumi,4] + 24
+                  }
                   if (nightsummary[sumi,3] > nightsummary[sumi,4]) {
                     nightsummary[sumi,5] = (36 - nightsummary[sumi,3]) + (nightsummary[sumi,4] - 12)
                   } else {
