@@ -35,6 +35,7 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
   if (length(which(ls() == "rmc.header.structure")) == 0) rmc.header.structure = c()
   if (length(which(ls() == "rmc.check4timegaps")) == 0) rmc.check4timegaps = FALSE
   if (length(which(ls() == "rmc.col.wear")) == 0) rmc.col.wear = c()
+  if (length(which(ls() == "rmc.doresample")) == 0) rmc.doresample = FALSE
   
   # function wrapper to read blocks of accelerationd data from various brands
   # the code identifies which accelerometer brand and data format it is
@@ -280,7 +281,7 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
                           dec=decn,showProgress = FALSE, header = freadheader))
     },silent=TRUE)
     if (length(P) > 1) {
-      P = as.matrix(P)
+      P = data.matrix(P) # as.matrix turned num to char if there are missing values.
       if (nrow(P) < ((sf*ws*2)+1) & blocknumber == 1) {
         P = c() ; switchoffLD = 1 #added 30-6-2012
         filequality$filetooshort = TRUE
@@ -430,7 +431,8 @@ g.readaccfile = function(filename,blocksize,blocknumber,selectdaysfile=c(),fileq
                                  rmc.headername.recordingid = rmc.headername.sn,
                                  rmc.header.structure = rmc.header.structure,
                                  rmc.check4timegaps = rmc.check4timegaps,
-                                 rmc.col.wear=rmc.col.wear)
+                                 rmc.col.wear=rmc.col.wear,
+                                 rmc.doresample=rmc.doresample)
     },silent=TRUE)
     if (length(sf) == 0) sf = rmc.sf
     if (length(P) == 2) {
